@@ -150,11 +150,12 @@ class PeptideSearch():
         dffinal.to_csv(str(self.Fasta_File)+"Matches.csv")
         return dffinal, N
     
-    def SequenceSearch(Peptide, Sequence):
+
+    def SequenceSearchs(Peptide, Sequence):
         Result, Index= -1, -1 
-        i= Sequence.find(Peptide)
-        if i>=0:
-            Index=i
+        x= Sequence.find(Peptide)
+        if x>=0:
+            Index=x
             Result=0
             return Result, Index
         
@@ -163,16 +164,25 @@ class PeptideSearch():
             str2= Peptide[q+1:]
             s1= Sequence.find(str1)
             s2= Sequence.find(str2)
-            if s2==(s1+len(str1)+1) or s1==0 or s2==0:
+
+            if len(str1)==0 and s2>=0:
+                Result=1
+                if (s2>0):
+                    Index=s2-1
+                else:
+                    Index=0
+            elif len(str2)==0 and s1>=0:
+                Result=1
+                Index=s1
+            elif s2==(s1+len(str1)+1):
                 Result=1
                 Index= s1
-                return Result, Index  
-        return Result, Index  
+        return Result, Index   
                     
 
 # p= PeptideSearch("Peptides.txt", "Test.fasta",)
 # df, pList= p.ExactMatch()
 # df2, N= p.OneMismatch(pList)
-# d, s= p.MatchFinder()
+#d, s= PeptideSearch.SequenceSearchs("sl", "abcsm")
 
 
